@@ -54,7 +54,7 @@ enum e_img_list_columns {
  * @param[in]  s_msg  Message to show
  * @return     1 if string is empty, 0 if it is not.
  */
-int    check_is_empty             (const char *s_str,
+int    str_is_empty_msg           (const char *s_str,
                                    const char *s_msg);
 /*----------------------------------------------------------------------------*/
 /**
@@ -66,7 +66,7 @@ int    check_is_empty             (const char *s_str,
  * @return     1 if string is made of alphanumeric chars and spaces,
  *             0 if it is not.
  */
-int    check_is_alnum_space       (const char *s_str,
+int    str_is_alnum_or_space      (const char *s_str,
                                    const char *s_msg);
 /*----------------------------------------------------------------------------*/
 /**
@@ -103,13 +103,15 @@ char * combo_get_active_str       (GtkWidget  *gw_combo,
  *
  * @param[out] gw_iconview  IconView to add image
  * @param[in]  si_item      SearchItem with image data
- * @param[in]  s_cache_dir  String with app's cache directory
+ * @param[in]  s_thumb_dir  String with app's cache directory
+ * @param[in]  s_wallp_dir  String with app's wallpaper directory
  * @param[in]  s_prefix     File name prefix
  * @return     none  
  */
 void   add_searchitem_to_img_view (GtkWidget        *gw_iconview,
                                    const SearchItem *si_item,
-                                   const char       *s_cache_dir,
+                                   const char       *s_thumb_dir,
+                                   const char       *s_wallp_dir,
                                    const char       *s_prefix);
 /*----------------------------------------------------------------------------*/
 #endif
