@@ -46,7 +46,7 @@ wms_update_wm_config (Setting *st_wms)
     char *s_path = NULL;   /* Config file path */
     int   i_res  = ERR_OK; /* Error output */
 
-    s_path = cfgfile_get_wm_info_home_path ();
+    s_path = cfgfile_get_wm_info_home_file_path ();
     i_res  = setts_check_update_file (s_path, st_wms);
     free (s_path);
     return i_res;
@@ -138,7 +138,7 @@ wms_get_wm_info_home (int *i_err)
 
     *i_err = 0;
 
-    s_path = cfgfile_get_wm_info_home_path ();
+    s_path = cfgfile_get_wm_info_home_file_path ();
     st_wms = setts_read (s_path, i_err);
 
     free (s_path);
@@ -157,7 +157,7 @@ wms_get_wm_info_data (int *i_err)
 
     *i_err = 0;
 
-    if ((s_path = cfgfile_get_wm_info_data_path (i_err)) != NULL) {
+    if ((s_path = cfgfile_get_wm_info_data_file_path (i_err)) != NULL) {
         st_wms = setts_read (s_path, i_err);
         free (s_path);
     }
@@ -256,7 +256,7 @@ wms_update_wm_command (const char *s_wm_name,
     int      i_err   = ERR_OK; /* Error output */
 
     /* Load settings from config file */
-    s_path = cfgfile_get_wm_info_home_path ();
+    s_path = cfgfile_get_wm_info_home_file_path ();
     st_wms = setts_read (s_path, &i_err);
     if (i_err != ERR_OK) {
         /* err (EXIT_FAILURE, NULL); */
